@@ -1,4 +1,4 @@
-/*
+/**
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
  * Keys.
@@ -6,21 +6,21 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
  */
 #ifndef __XMLSEC_KEYS_H__
 #define __XMLSEC_KEYS_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #include <time.h>
 
-#include <xmlsec/exports.h>
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/list.h>
 #include <xmlsec/keysdata.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
 
 /**
  * xmlSecKeyUsage:
@@ -32,28 +32,29 @@ typedef unsigned int                    xmlSecKeyUsage;
 /**
  * xmlSecKeyUsageSign:
  *
- * Key for signing.
+ * Key can be used in any way.
+
  */
 #define xmlSecKeyUsageSign              0x00000001
 
 /**
  * xmlSecKeyUsageVerify:
  *
- * Key for signature verification.
+ * Key for signing.
  */
 #define xmlSecKeyUsageVerify            0x00000002
 
 /**
  * xmlSecKeyUsageEncrypt:
  *
- * An encryption key.
+ * Key for signature verification.
  */
 #define xmlSecKeyUsageEncrypt           0x00000004
 
 /**
  * xmlSecKeyUsageDecrypt:
  *
- * A decryption key.
+ * An encryption key.
  */
 #define xmlSecKeyUsageDecrypt           0x00000008
 
@@ -67,7 +68,7 @@ typedef unsigned int                    xmlSecKeyUsage;
 /**
  * xmlSecKeyUsageAny:
  *
- * Key can be used in any way.
+ * A decryption key.
  */
 #define xmlSecKeyUsageAny               0xFFFFFFFF
 
